package com.ruoyi.framework.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.framework.system.mapper.DiagnosisUpdatesMapper;
import com.ruoyi.framework.system.domain.DiagnosisUpdates;
import com.ruoyi.framework.system.service.IDiagnosisUpdatesService;

/**
 * 诊断数据更新Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-11-13
 */
@Service
public class DiagnosisUpdatesServiceImpl implements IDiagnosisUpdatesService 
{
    @Autowired
    private DiagnosisUpdatesMapper diagnosisUpdatesMapper;

    /**
     * 查询诊断数据更新
     * 
     * @param UpdateID 诊断数据更新主键
     * @return 诊断数据更新
     */
    @Override
    public DiagnosisUpdates selectDiagnosisUpdatesByUpdateID(Long UpdateID)
    {
        return diagnosisUpdatesMapper.selectDiagnosisUpdatesByUpdateID(UpdateID);
    }

    /**
     * 查询诊断数据更新列表
     * 
     * @param diagnosisUpdates 诊断数据更新
     * @return 诊断数据更新
     */
    @Override
    public List<DiagnosisUpdates> selectDiagnosisUpdatesList(DiagnosisUpdates diagnosisUpdates)
    {
        return diagnosisUpdatesMapper.selectDiagnosisUpdatesList(diagnosisUpdates);
    }

    /**
     * 新增诊断数据更新
     * 
     * @param diagnosisUpdates 诊断数据更新
     * @return 结果
     */
    @Override
    public int insertDiagnosisUpdates(DiagnosisUpdates diagnosisUpdates)
    {
        return diagnosisUpdatesMapper.insertDiagnosisUpdates(diagnosisUpdates);
    }

    /**
     * 修改诊断数据更新
     * 
     * @param diagnosisUpdates 诊断数据更新
     * @return 结果
     */
    @Override
    public int updateDiagnosisUpdates(DiagnosisUpdates diagnosisUpdates)
    {
        return diagnosisUpdatesMapper.updateDiagnosisUpdates(diagnosisUpdates);
    }

    /**
     * 批量删除诊断数据更新
     * 
     * @param UpdateIDs 需要删除的诊断数据更新主键
     * @return 结果
     */
    @Override
    public int deleteDiagnosisUpdatesByUpdateIDs(Long[] UpdateIDs)
    {
        return diagnosisUpdatesMapper.deleteDiagnosisUpdatesByUpdateIDs(UpdateIDs);
    }

    /**
     * 删除诊断数据更新信息
     * 
     * @param UpdateID 诊断数据更新主键
     * @return 结果
     */
    @Override
    public int deleteDiagnosisUpdatesByUpdateID(Long UpdateID)
    {
        return diagnosisUpdatesMapper.deleteDiagnosisUpdatesByUpdateID(UpdateID);
    }
}
